@@ -17,8 +17,9 @@ class Reaktor:
 		self.__api = "http://api.reaktor.io/"
 		
 		d = {
-			"mail": mail, 
-			"pass": hashlib.md5(password).hexdigest()
+			"mail"  : mail, 
+			"pass"  : hashlib.md5(password).hexdigest(),
+			"client": "py"
 		}
 
 		# create POST request to login
@@ -30,7 +31,6 @@ class Reaktor:
 		# validate result of login
 		if bool(res["ok"]) == True:
 			self.__token = res["token"]
-
 		else:
 			raise Exception(res["reason"])
 
@@ -41,6 +41,7 @@ class Reaktor:
 	# triggers an reaktor.io event by its name
 	#
 	# name: the name of the event in reaktor.io system
+	# data: the data object to fill in the variables in template
 	# save: (optional) waits till event is triggered and returns a 
 	#		boolean of its status. default is False, so the event will 
 	# 		be triggered asyncroniously and returns True
@@ -48,19 +49,19 @@ class Reaktor:
 	def trigger(self, name, data=None, safe=False):
 
 		d = {
-			"token": self.__token,
-			"name" : name, 
-			"safe" : safe
+			"token" : self.__token,
+			"name"  : name, 
+			"safe"  : safe,
+			"client": "py"
 		}
 
 		# if specified append data object
-		if data: d["data"] = json.dumps(data)
+		if data: d["data"] = data
 
-		# fire trigger event on
-		req = urllib2.urlopen(self.__api + "trigger", urllib.urlencode(d))
-
-		# parse result
-		res = json.loads(req.read())
+		req = urllib2.Request(self.__api + "trigger", json.dumps(d), {"Content-Type": "application/json"})
+		f = urllib2.urlopen(req)
+		res = json.loads(f.read())
+		f.close()
 
 		# validate result
 		if bool(res["ok"]) == True:
